@@ -1,4 +1,4 @@
-'''
+r'''
 # aws-kinesisstreams-kinesisfirehose-s3 module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -122,6 +122,9 @@ Out of the box implementation of the Construct without any override will set the
 
 © Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
